#### Online Appendix 9.1 ####

# load packages
  library(mgcv)
  library(MASS)

# load data
  Ptarmigan=read.csv(file.choose())

# 1) fit gam to log transformed data   
  Ptarmigan.gam <- gam(log(CockDensity) ~ factor(Area) + s(Year), data = Ptarmigan)

# plot the fitted s() curve
  plot(Ptarmigan.gam)  

# estimated parameters, fitted values, and residuals
# output not shown
  coefficients(Ptarmigan.gam)
  fitted(Ptarmigan.gam)
  residuals(Ptarmigan.gam)

# summary table
  summary(Ptarmigan.gam)

# obtain degrees of freedom for trend curve and aic
  summary(Ptarmigan.gam)$edf   # 8.85523 
  Ptarmigan.gam$aic            # 181.5483

# 2) fix degrees of freedom for trend curve 
  Ptarmigan.gam3 <- gam(log(CockDensity) ~ factor(Area) + s(Year, k=17, fx=TRUE), data= Ptarmigan)


# calculate AIC for models with different df
  dfs <- 5:25
  AIC <- c()
  for(i in 1:length(dfs)){
  	tmp.gam.fit <- gam(log(CockDensity) ~ factor(Area) + s(Year, k=dfs[i], fx=TRUE), data= Ptarmigan)
  	AIC[i] <- tmp.gam.fit$aic
  }

  plot(dfs, AIC)	


# calculate the index 
 # choose settings
  # years we want an index estimate
  PredYears <- 1981:2016    
    # for more better looking plots we can use
    # PredYears <- seq(1981,2016, by=0.2) 
  
# use first year as base year
  base <- 1
  
# set the area, we chose Holl
  NewDat <- data.frame(Year = PredYears, Area = "Holl")  # can pick any Area

# calculate index from the fitted trend curve
  s.term <- predict.gam(Ptarmigan.gam, newdata = NewDat, type='terms', terms="s(Year)")
  index.hat <- exp(s.term - s.term[base])  

# uncertainty bounds for the index 
 # set number of posterior samples
   nPost <- 1000      

 # get nPost posterior samples of the index
   Xp <- predict(Ptarmigan.gam, newdata=NewDat, type='lpmatrix')
   nYears <- length(PredYears)
   PostCoef <- mvrnorm(n = nPost, coef(Ptarmigan.gam), Ptarmigan.gam$Vp)
   s.terms <- Xp %*% t(PostCoef)
   Index <- exp( s.terms - matrix(rep(s.terms[base, ], nYears), byrow=T, ncol= nPost) )

 # calculate posterior means and bounds for 95% CI
   IndexPostMean <- apply(Index, 1, mean)
   PostLB <- apply(Index, 1, quantile, prob=0.025)
   PostUB <- apply(Index, 1, quantile, prob=0.975)

 # build plot
   plot(PredYears, IndexPostMean, type='l', ylim=range(PostLB, PostUB))
   lines(PredYears, PostLB, type='l', lty=2)
   lines(PredYears, PostUB, type='l', lty=2)
   points(PredYears, index.hat)
